@@ -1214,7 +1214,7 @@ class GeoArray(object):
                                       res_factor=res_factor, nodataVal=nodataVal, ignore_rotation=ignore_rotation)
 
         palette, vmin, vmax = self._get_cmap_vmin_vmax(cmap, vmin, vmax, pmin, pmax, image2plot, nodataVal)
-        if nodataVal is not None and np.std(image2plot) != 0:
+        if nodataVal is not None and np.std(image2plot.astype(np.float)) != 0:
             image2plot = np.ma.masked_equal(image2plot, nodataVal)
 
         # check availability of holoviews
@@ -1256,7 +1256,7 @@ class GeoArray(object):
                 ax = plt.gca()
 
             rows, cols = image2plot.shape[:2]
-            im = ax.imshow(image2plot,
+            im = ax.imshow(image2plot.astype(np.int),
                            palette,
                            interpolation=interpolation,
                            extent=(0, cols, rows, 0),
